# lusid-python-tools
Python tools for the LUSID

The PyPi package for lusid-python-tools can installed using the following command:
```
$ pip install lusidtools
```

![](https://github.com/finbourne/lusid-python-tools/workflows/commit-hook/badge.svg)
[![Build Status](https://travis-ci.org/finbourne/lusid-python-tools.svg?branch=master)](https://travis-ci.org/finbourne/lusid-python-tools)

For more details see the lusid-python-tools [wiki](https://github.com/finbourne/lusid-python-tools/wiki).
